@@ -14,20 +14,18 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-# This is necessary on Python 2.7 because of the local bandit module
-# (bandit.bandit), without from bandit.core will fail since bandit.bandit has
-# no submodule "core"
-from __future__ import absolute_import
+import pbr.version
 
 from bandit.core import config  # noqa
 from bandit.core import context  # noqa
 from bandit.core import manager  # noqa
 from bandit.core import meta_ast  # noqa
 from bandit.core import node_visitor  # noqa
-from bandit.core import result_store  # noqa
 from bandit.core import test_set  # noqa
 from bandit.core import tester  # noqa
 from bandit.core import utils  # noqa
 from bandit.core.constants import *  # noqa
-from bandit.core.objects import *  # noqa
+from bandit.core.issue import *  # noqa
 from bandit.core.test_properties import *  # noqa
+
+__version__ = pbr.version.VersionInfo('bandit').version_string()
