@@ -8,3 +8,6 @@ pop(['ls', '-l'], shell=False)
 pop(['/bin/ls', '-l'], shell=False)
 
 pop('../ls -l', shell=False)
+
+pop('c:\hello\something', shell=False)
+pop('c:/hello/something_else', shell=False)
